(api-formats)=

# Formats

This page documents the API of the `crowsetta.formats` module.
It is generated automatically. 
If you are a crowsetta user looking for 
more detail about the built-in formats,
please see: {ref}`formats-index`.

```{eval-rst}
.. autosummary::
   :toctree: generated
   :template: module.rst
   :recursive:

   crowsetta.formats
   crowsetta.formats.bbox
   crowsetta.formats.seq
```
